@@ -44,15 +44,6 @@ public:
     {
     }
 
-    bool eventFilter(QObject *watched, QEvent *event) override
-    {
-        if (event->type() == QEvent::Show && watched == q) {
-            Q_ASSERT(m_notifyEnabled);
-            doNotify();
-        }
-        return false;
-    }
-
     void doNotify()
     {
 #ifndef Q_OS_WIN // FIXME problems with KNotify on Windows
@@ -65,17 +56,14 @@ public:
         case KMessageDialog::WarningTwoActions:
         case KMessageDialog::WarningTwoActionsCancel:
         case KMessageDialog::WarningContinueCancel:
+            notifyType = QMessageBox::Warning;
+            break;
         case KMessageDialog::Information:
             notifyType = QMessageBox::Information;
             break;
         case KMessageDialog::Error:
             notifyType = QMessageBox::Critical;
             break;
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
-        case KMessageDialog::Sorry:
-            notifyType = QMessageBox::Warning;
-            break;
-#endif
         }
 
         // TODO include m_listWidget items
@@ -188,9 +176,6 @@ KMessageDialog::KMessageDialog(KMessageDialog::Type type, const QString &text, Q
     d->m_topLayout->addWidget(d->m_buttonBox);
 
     // Default buttons
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 100)
-    setButtons();
-#else
     if ((d->m_type == KMessageDialog::Information) || (d->m_type != KMessageDialog::Error)) {
         // set Ok button
         setButtons();
@@ -198,7 +183,6 @@ KMessageDialog::KMessageDialog(KMessageDialog::Type type, const QString &text, Q
         // set Continue & Cancel buttons
         setButtons(KStandardGuiItem::cont(), KGuiItem(), KStandardGuiItem::cancel());
     }
-#endif
 
     setNotifyEnabled(true);
 
@@ -269,11 +253,6 @@ void KMessageDialog::setCaption(const QString &caption)
     case KMessageDialog::Information:
         title = QApplication::translate("KMessageDialog", "Information");
         break;
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
-    case KMessageDialog::Sorry:
-        title = QApplication::translate("KMessageDialog", "Sorry");
-        break;
-#endif
     case KMessageDialog::Error: {
         title = QApplication::translate("KMessageDialog", "Error");
         break;
@@ -298,9 +277,6 @@ void KMessageDialog::setIcon(const QIcon &icon)
         case KMessageDialog::WarningTwoActions:
         case KMessageDialog::WarningTwoActionsCancel:
         case KMessageDialog::WarningContinueCancel:
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
-        case KMessageDialog::Sorry:
-#endif
             effectiveIcon = style->standardIcon(QStyle::SP_MessageBoxWarning, nullptr, this);
             break;
         case KMessageDialog::Information:
@@ -410,15 +386,7 @@ void KMessageDialog::setButtons(const KGuiItem &primaryAction, const KGuiItem &s
     case KMessageDialog::WarningContinueCancel: {
         d->m_buttonBox->setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::Cancel);
 
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 100)
-        KGuiItem continueItem = primaryAction;
-        if (continueItem.text() == KStandardGuiItem::yes().text()) {
-            continueItem = KStandardGuiItem::cont();
-        }
-        KGuiItem::assign(d->m_buttonBox->button(QDialogButtonBox::Yes), continueItem);
-#else
         KGuiItem::assign(d->m_buttonBox->button(QDialogButtonBox::Yes), primaryAction);
-#endif
 
         auto *cancelButton = d->m_buttonBox->button(QDialogButtonBox::Cancel);
         KGuiItem::assign(cancelButton, cancelAction);
@@ -427,9 +395,6 @@ void KMessageDialog::setButtons(const KGuiItem &primaryAction, const KGuiItem &s
         break;
     }
     case KMessageDialog::Information:
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 97)
-    case KMessageDialog::Sorry:
-#endif
     case KMessageDialog::Error: {
         d->m_buttonBox->setStandardButtons(QDialogButtonBox::Ok);
         auto *okButton = d->m_buttonBox->button(QDialogButtonBox::Ok);
@@ -502,11 +467,14 @@ bool KMessageDialog::isNotifyEnabled() const
 void KMessageDialog::setNotifyEnabled(bool enable)
 {
     d->m_notifyEnabled = enable;
-    if (enable) {
-        installEventFilter(d.get());
-    } else {
-        removeEventFilter(d.get());
+}
+
+void KMessageDialog::showEvent(QShowEvent *event)
+{
+    if (d->m_notifyEnabled) {
+        d->doNotify();
     }
+    QDialog::showEvent(event);
 }
 
 #include "kmessagedialog.moc"
